# History

## 0.1.9 (2019-05-05)

* [#7 Include GeoPandas Integration](https://github.com/bellockk/alphashape/issues/7)

## 0.1.8 (2019-05-05)

* [#8 Include capability to optimize alpha parameter](https://github.com/bellockk/alphashape/issues/8)

## 0.1.7 (2019-04-26)

* Complete code coverage of existing capabilities.

## 0.1.6 (2019-04-24)

* [#6 Include Jupyter Notebook in Examples](https://github.com/bellockk/alphashape/issues/6)

## 0.1.5 (2019-04-24)

* [#5 Create an Example Gallery in the Documentation](https://github.com/bellockk/alphashape/issues/5)

## 0.1.4 (2019-04-24)

* Bug fixes.

## 0.1.3 (2019-04-24)

* Bug fixes.

## 0.1.2 (2019-04-24)

* Bug fixes.

## 0.1.1 (2019-04-24)

* Bug fixes.

## 0.1.0 (2019-04-23)

* First release on PyPI.
